/*
 *  Linux kernel adaptation layers for owl wifi library.
 *  Copyright (C) 2010 HD Wireless AB
 *
 */

#ifndef OWL_NET_H
#define OWL_NET_H

#include <linux/skbuff.h>
#include <linux/netdevice.h>
#include <linux/etherdevice.h>
#include <linux/wireless.h>
#include <linux/timer.h>

#include "wl_api.h"

#define OWL_MAX_KEY_LEN 32

struct key_info {
        char key[OWL_MAX_KEY_LEN];
        unsigned char len;
};

struct owl_net {
        struct owl_transport *transport;
        struct net_device *dev;
        struct net_device_stats stats;
        wait_queue_head_t waitq;
        unsigned long flags;
#define INIT_COMPLETE           0
#define SCAN_COMPLETE           1

        struct semaphore wl_sema;
        struct timer_list wl_timer;
        struct work_struct wl_work;

        struct iw_statistics wireless_stats;

        enum wl_auth_mode auth_mode;
        
        struct key_info key_info[4];
        unsigned int default_key;
        int auth_param[13]; /* wireless.h */

        unsigned int ps_traffic_timeout;
        unsigned int ps_enabled;
        struct wl_ssid_t ssid;
        uint8_t channel;
};

struct owl_transport {
        void (*tx)(struct owl_transport *transport, struct sk_buff *skb);
        int (*fw_download)(struct owl_transport *transport);
        void (*wakeup)(struct owl_transport *transport, int wakeup);
    
        /* written by owl_net, should not be touched by owl_drv */
        void *net;
};

void owl_net_rx(struct owl_transport *transport, struct sk_buff *skb);
int owl_net_register_drv(struct owl_transport *transport);
void owl_net_unregister_drv(struct owl_transport *transport);

#endif
